.. _introduction:

============
Introduction
============

This short tutorial will give you an overview of the `aiocouch` library.

You can directly jump to particular sections using the *Navigation* on the left.
